/* *********************************************************
               Function declarations
  ********************************************************* */

void Initialize(void);
void feed(void);

void IRQ_Routine (void)   __attribute__ ((interrupt("IRQ")));
void FIQ_Routine (void)   __attribute__ ((interrupt("FIQ")));
void SWI_Routine (void)   __attribute__ ((interrupt("SWI")));
void UNDEF_Routine (void) __attribute__ ((interrupt("UNDEF")));

/**********************************************************
                  Header files
 **********************************************************/
#include "lpc21xx.h"

#define   ST_LED_OFF	IOSET0  = (1 << 12)
#define   ST_LED_ON		IOCLR0  = (1 << 12)
#define   ST_LED_CONF	IODIR0 |= (1 << 12)

/**********************************************************
                       MAIN
**********************************************************/
static 	int		j;										// loop counter (stack variable)

int	main (void) {
	
	
	// Initialize the system
	Initialize();
 
	// endless loop to toggle the GREEN LED
	while (1) 
	{
		ST_LED_ON;
		for (j = 0; j < 500000; j++ );		// wait 500 msec
		ST_LED_OFF;
		for (j = 0; j < 500000; j++ );
	}
}



/**********************************************************
                      Initialize
**********************************************************/

#define PLOCK 0x400

void Initialize(void)
{
	//M=3(4?),P=1(2?) PLLfreq = 58.9824 Mhz, CCLK = 14,7456 Mhz
	PLLCFG = 0x00000023;
	PLLFEED = 0xAA;
	PLLFEED = 0x55;

	// Enable the PLL
	PLLCON |= 0x01;
	PLLFEED = 0xAA;
	PLLFEED = 0x55;
	while(!(PLLSTAT & PLOCK));  // Wait for PLL to lock

	//Init MAM & Flash memory fetch
	MAMCR = 0x00;
	MAMTIM = 0x03;
	MAMCR = 0x02;

	// configure peripherals speed
	VPBDIV = 0x01; //pclk = cclk
	
	// Connect the PLL as the clock source
	PLLCON=0x3;
	PLLFEED = 0xAA;
	PLLFEED = 0x55;

	//GPIO init
	ST_LED_OFF;
	PINSEL0 = 0; //P0 lower 16 bits all GPIO
	PINSEL1 = 0; //P0 upper 16 bits all GPIO

	// configure the LED pin
	ST_LED_CONF;
}


/*  Stubs for various interrupts (may be replaced later)  */
/*  ----------------------------------------------------  */

void IRQ_Routine (void) {
	while (1) ;	
}

void FIQ_Routine (void)  {
	while (1) ;	
}


void SWI_Routine (void)  {
	while (1) ;	
}


void UNDEF_Routine (void) {
	while (1) ;	
}

